Extension traits and implementations for Element (see minidom crate).
Description
OnlyChildElementExt: provides helper to extract one and only one child of anElementAttributeElementExt: provides helper to extract and parse into desired type an attribute of anElement
Examples
Follow the links to see some example:
Enums
- Error type for
minidom_ext
Traits
- Get an attribute from an element.
- Get the one and only child of an element.